{#advimage_dlg.dialog_title}

- {#advimage_dlg.tab_general}
- {#advimage_dlg.tab_appearance}
- {#advimage_dlg.tab_advanced}

{#advimage_dlg.src}
{#advimage_dlg.image_list}
{#advimage_dlg.alt}
{#advimage_dlg.title}
{#advimage_dlg.preview}
{#advimage_dlg.tab_appearance}
{#advimage_dlg.align}
Lorem ipsum, Dolor sit amet, consectetuer adipiscing loreum ipsum edipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat.Loreum ipsum edipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat.
{#advimage_dlg.dimensions}
x px {#advimage_dlg.constrain_proportions}
{#advimage_dlg.vspace}
{#advimage_dlg.hspace}
{#advimage_dlg.border}
{#class_name}
{#advimage_dlg.style}
{#advimage_dlg.classes}
{#advimage_dlg.swap_image} {#advimage_dlg.alt_image}

{#advimage_dlg.mouseover} |
{#advimage_dlg.image_list} |
{#advimage_dlg.mouseout} |
{#advimage_dlg.image_list} |

{#advimage_dlg.misc}

{#advimage_dlg.id} |
{#advimage_dlg.langdir} |
{#advimage_dlg.langcode} |
{#advimage_dlg.map} |
{#advimage_dlg.long_desc} |